@@ -135,7 +135,7 @@ class NiryoRobot(object):
         if answer_status not in ["OK", "KO"]:
             raise InvalidAnswerException(answer_status)
         if received_dict["status"] != "OK":
-            raise NiryoOneException("Command KO : {}".format(received_dict["message"]))
+            raise NiryoRobotException("Command KO : {}".format(received_dict["message"]))
         list_ret_param = received_dict["list_ret_param"]
         if len(list_ret_param) == 1:
             list_ret_param = list_ret_param[0]
@@ -554,7 +554,7 @@ class NiryoRobot(object):
 
     def get_pose_saved(self, pose_name):
         """
-        Get pose saved in from Niryo One's memory
+        Get pose saved in from Ned's memory
         
         :param pose_name: Pose name in robot's memory
         :type pose_name: str 
@@ -654,7 +654,7 @@ class NiryoRobot(object):
     # - Trajectories
     def get_trajectory_saved(self, trajectory_name):
         """
-        Get trajectory saved in Niryo One's memory
+        Get trajectory saved in Ned's memory
 
         :type trajectory_name: str
         :return: Trajectory
@@ -665,7 +665,7 @@ class NiryoRobot(object):
 
     def execute_trajectory_saved(self, trajectory_name):
         """
-        Execute trajectory from Niryo One's memory
+        Execute trajectory from Ned's memory
 
         :type trajectory_name: str
         :rtype: None
@@ -1144,7 +1144,7 @@ class NiryoRobot(object):
 
         Example::
 
-            robot = NiryoOneClient(ip_address="x.x.x.x")
+            robot = NiryoRobot(ip_address="x.x.x.x")
             robot.calibrate_auto()
             robot.move_pose(<observation_pose>)
             obj_found, shape_ret, color_ret = robot.vision_pick(<workspace_name>,
